A data set containing simulated and processed readmissions data for 500 hospitals with
three continuous covariates. This is the form of the data needed to use fe.prov.
hospital_preparedA data.frame with 24438 rows and 8 variables (columns):
Indicator for readmission; 1=Yes, 0=No; numeric
Provider ID; numeric
Simulated covariate 1, numeric
Simulated covariate 2, numeric
Simulated covariate 3, numeric
variable 'included' as an indicator
providers with no readmission within 30 days
providers with all readmissions within 30 days